// Requality: CKEditor plugin
// Implements functions used by the UniEditor component of the Requality project
// Details:
//   1. New toolbar button RequalitySave that saves changes and closes the editor.
//   2. New toolbar button RequalityExit that closes the editor without saving
//      changes (confirmation message is shown if changes are present).

// TODO: Calling requalitySave/requalityExit causes JS errors. Probably, editor
// instance is destroyed too early. Find out how to work around the problem!
(function() {
		// Command implementing RequalitySave action
	var saveCmd = {
		exec: function (ed) {
			var elem = ed.element.$;
			try{
				ed.destroy();
			}catch(ex){}
			if(editor == ed)
				editor = null;
			closeStarted = false;
			if(elem){
				onChangeNode(extractUUID(elem.id));
			}
		},
		modes : { wysiwyg : 1, source : 1 }  
	};
	// Command implementing RequalityExit action
	var savedid;
	var exitCmd = {
		exec: function (ed) {
			var elem;
			var saveid;
			try{
				ed.resetDirty();
				elem = ed.element.$;
				saveid = elem.id;
				ed.destroy();
			}catch(ex){}
			if(editor == ed)
				editor = null;
			closeStarted = false;
			if(elem){
				onChangeNode(extractUUID(elem.id));
			}
			if(elem)
				$("#"+saveid).prop('contenteditable', 'false');
		},
		modes : { wysiwyg : 1, source : 1 }  
	};
	var buttonEditCmd = {
		exec: function (ed) {
			closeStarted = true;
			editorJavaDialog = true;
			if (ed.checkDirty() && !confirm('There are unsaved changes that will be lost. Continue?')) {
				return;
			}
			editorJavaDialog = false;
			ed.element.$.setAttribute('contenteditable', 'false');
			ed.execCommand('requalityExit');
		},
		modes : { wysiwyg : 1, source : 1 }  			
	};

	// Register the new plugin named "requality".
	CKEDITOR.plugins.add('requality', {
		icons: 'requalityexit,requalitysave',
		init: function (editor) {
			editor.addCommand('requalitySave', saveCmd);
			editor.addCommand('requalityExit', exitCmd);
			editor.addCommand('requalityButtonExit', buttonEditCmd);
			editor.ui.addButton('RequalitySave', {
				label: 'Save changes and close editor',
				command: 'requalitySave'
			});
			editor.ui.addButton('RequalityExit', {
				label: 'Close editor discarding changes',
				command: 'requalityButtonExit'
			});
		}
	});
})();
